@@ -80,8 +80,8 @@ def format_coco_file(imgdir, annotations, train_assets, test_assets):
 
 def format_segmentation(shape):
     polygon = []
-    xs = shape[::2]
-    ys = shape[1::2]
+    xs = shape[0][::2]
+    ys = shape[0][1::2]
     for x, y in list(zip(xs, ys)):
         polygon.append([x, y])
     return polygon
